@@ -5,7 +5,7 @@
  *                                                                    *
  *   Module MD - Machine dependent logic                              *
  *                                                                    *
- *   Copyright (C) R.D. Eager                        MCMXCIV          *
+ *   Copyright (C) R.D. Eager                        MMXVIII          *
  *                 P.J. Brown   University of Kent   MCMLXVII         *
  *                                                                    *
  **********************************************************************
@@ -51,6 +51,8 @@
  *          independent version changed to CKN.
  * 4.11 --  Update to handle clang on FreeBSD; machine independent version
  *          changed to CKO.
+ * 4.12 --  Update to handle 64 bit FreeBSD; machine independent version
+ *          changed to CKP.
  *
  */
 
@@ -120,7 +122,7 @@ S10 upwards are used by the machine-dependent logic
 
 /*** Machine dependent definitions ***/
 
-#if	ATT3B | BSD4 | FBSD| IBMC | L1 | MSC | VMS | WIN
+#if	ATT3B | BSD4 | FBSD32| FBSD64 | IBMC | L1 | MSC | VMS | WIN
 #define	PROGNAME	progname	/* Present OK on these systems */
 #endif
 #if	ZTC | ZTCX
@@ -136,7 +138,7 @@ S10 upwards are used by the machine-dependent logic
 
 /*** Version number and system description ***/
 
-#define MDVERSION	"4.11"		/* Version number of machine dependent logic */
+#define MDVERSION	"4.12"		/* Version number of machine dependent logic */
 
 #if	ATT3B
 #define	MDSYSTEM	"AT&T 3B"	/* System on which program runs */
@@ -144,8 +146,11 @@ S10 upwards are used by the machine-dependent logic
 #if	BSD4
 #define	MDSYSTEM	"4.3BSD"	/* System on which program runs */
 #endif
-#if	FBSD
-#define	MDSYSTEM	"FreeBSD"	/* System on which program runs */
+#if	FBSD32
+#define	MDSYSTEM	"FreeBSD (32 bit)" /* System on which program runs */
+#endif
+#if	FBSD64
+#define	MDSYSTEM	"FreeBSD (64 bit)" /* System on which program runs */
 #endif
 #if	IBMC
 #define	MDSYSTEM	"OS/2"		/* System on which program runs */
@@ -178,7 +183,7 @@ static	FILE	*in_fps[MAXIN+1];/* Vector of input file pointers */
 static	FILE	*out_fps[MAXOUT+1];/* Vector of output file pointers */
 static	FILE	*list_fp;	/* File pointer for listing file */
 static	FILE	*err_fp;	/* File pointer for debugging file */
-#if	ATT3B | BSD4 | FBSD | IBMC | L1 | MSC | VMS | WIN
+#if	ATT3B | BSD4 | FBSD32 | FBSD64 | IBMC | L1 | MSC | VMS | WIN
 static	char	*progname;	/* Pointer to argv[0] */
 #endif
 
@@ -236,7 +241,7 @@ char	*argv[];
 #if	MSC | WIN | ZTC | ZTCX
 VOID main(int argc,char *argv[])
 #endif
-#if	FBSD | IBMC
+#if	FBSD32 | FBSD64 | IBMC
 int main(int argc,char *argv[])
 #endif
 /* Main initialisation routine. Reads and decodes the parameter string,
@@ -252,7 +257,7 @@ opens files, and obtains workspace. */
 	char *ptr;
 #endif
 
-#if	ATT3B | BSD4 | FBSD | IBMC | L1 | VMS
+#if	ATT3B | BSD4 | FBSD32 | FBSD64 | IBMC | L1 | VMS
 	progname = argv[0];
 #endif
 #if	MSC | WIN
@@ -280,7 +285,7 @@ opens files, and obtains workspace. */
 #if	IBMC | MSC | WIN
 		if((strlen(s) > 1) && (*s == '-' || *s == '/')) {
 #endif
-#if	ATT3B | BSD4 | FBSD | L1 | VMS | ZTC | ZTCX
+#if	ATT3B | BSD4 | FBSD32 | FBSD64 | L1 | VMS | ZTC | ZTCX
 		if((strlen(s) > 1) && (*s == '-')) {
 #endif
 			for(;;) {
@@ -302,7 +307,7 @@ opens files, and obtains workspace. */
 							while(isdigit((ch = *s++))) {
 								worksize = worksize*10 + (ch - '0');
 							}
-#if	ATT3B | BSD4 | FBSD | IBMC | MSC | VMS | WIN | ZTC
+#if	ATT3B | BSD4 | FBSD32 | FBSD64 | IBMC | MSC | VMS | WIN | ZTC
 							if(worksize < 200) {
 #endif
 #if	L1
@@ -352,7 +357,7 @@ opens files, and obtains workspace. */
 	workad = (INT *) sbrk(((int) worksize)*sizeof(INT));
 	if(workad == ((INT *) -1)) fail("cannot get workspace");
 #endif
-#if	FBSD | IBMC | L1 | MSC | VMS | WIN | ZTC | ZTCX
+#if	FBSD32 | FBSD64 | IBMC | L1 | MSC | VMS | WIN | ZTC | ZTCX
 	workad = (INT *) malloc(((unsigned) worksize)*sizeof(INT));
 	if(workad == ((INT *) NULL)) fail("cannot get workspace");
 #endif
@@ -385,7 +390,7 @@ opens files, and obtains workspace. */
 #if	ATT3B | BSD4 | L1
 	exit(res == 0 ? 0: 254);
 #endif
-#if	FBSD | MSC | WIN | ZTC | ZTCX
+#if	FBSD32 | FBSD64 | MSC | WIN | ZTC | ZTCX
 	exit(res == 0 ? EXIT_SUCCESS: EXIT_FAILURE);
 #endif
 #if	IBMC
@@ -595,10 +600,10 @@ input translation (using S16 and S17). */
 		if(ret == -1) {			/* Error */
 			*at_s12 += 10;		/* Ensure this message comes out */
 			prerr();
-#if	ATT3B | BSD4 | FBSD | IBMC | MSC | VMS | WIN | ZTC | ZTCX
+#if	ATT3B | BSD4 | FBSD32 | IBMC | MSC | VMS | WIN | ZTC | ZTCX
 			mderpr("\nCannot rewind input stream %d\n",s10);
 #endif
-#if	L1
+#if	FBSD64 | L1
 			mderpr("\nCannot rewind input stream %ld\n",s10);
 #endif
 			mdabort();
@@ -620,7 +625,7 @@ input translation (using S16 and S17). */
 
 	if(c == *at_s16) c = *at_s17;
 
-#if	!BSD4 & !FBSD & !IBMC & !MSC & !WIN & !ZTC & !ZTCX
+#if	!BSD4 & !FBSD32 & !FBSD64 & !IBMC & !MSC & !WIN & !ZTC & !ZTCX
 	if((c & 0x80) != 0) {
 		ersic();			/* Illegal input character */
 		c = ERRCHAR;			/* Substitute the 'error character' */
@@ -778,10 +783,10 @@ if required. */
 	if(nlpend) {
 		(*at_s19)++;			/* Update output line number */
 		if((list_fp != (FILE *) NULL) && (s20 == 2)) {
-#if	ATT3B | BSD4 | FBSD | IBMC | MSC | VMS | WIN | ZTC | ZTCX
+#if	ATT3B | BSD4 | FBSD32 | IBMC | MSC | VMS | WIN | ZTC | ZTCX
 			fprintf(list_fp,"%5d.   ",*at_s19);
 #endif
-#if	L1
+#if	FBSD64 | L1
 			fprintf(list_fp,"%5ld.   ",*at_s19);
 #endif
 		}
@@ -829,10 +834,10 @@ A suitable message is sent to the debugging file, and the process is
 aborted. */
 {	*at_s12 += 10;				/* Ensure this message comes out */
 	prerr();
-#if	ATT3B | BSD4 | FBSD | IBMC | MSC | VMS | WIN | ZTC | ZTCX
+#if	ATT3B | BSD4 | FBSD32 | IBMC | MSC | VMS | WIN | ZTC | ZTCX
 	mderpr("\nError while writing to output stream %d\n",file_number);
 #endif
-#if	L1
+#if	FBSD64 | L1
 	mderpr("\nError while writing to output stream %ld\n",file_number);
 #endif
 	mdabort();
@@ -895,10 +900,10 @@ VOID mdpostmort(VOID)
 #if	MSC | ZTC
 	fprintf(stderr,"\n\nBackwards stack:   (lfpt = %4x)\n",(INT) lfpt);
 #endif
-#if	ATT3B | FBSD | IBMC | BSD4 | VMS | WIN | ZTCX
+#if	ATT3B | FBSD32 | IBMC | BSD4 | VMS | WIN | ZTCX
 	fprintf(stderr,"\n\nBackwards stack:   (lfpt = %8x)\n",(INT) lfpt);
 #endif
-#if	L1
+#if	FBSD64 | L1
 	fprintf(stderr,"\n\nBackwards stack:   (lfpt = %8lx)\n",(INT) lfpt);
 #endif
 	n = lfpt - 30;
@@ -907,10 +912,10 @@ VOID mdpostmort(VOID)
 #if	MSC | ZTC
 	fprintf(stderr,"\n\nForwards stack:    (ffpt = %4x)\n",(INT) ffpt);
 #endif
-#if	ATT3B | BSD4 | FBSD | IBMC | VMS | WIN | ZTCX
+#if	ATT3B | BSD4 | FBSD32 | IBMC | VMS | WIN | ZTCX
 	fprintf(stderr,"\n\nForwards stack:    (ffpt = %8x)\n",(INT) ffpt);
 #endif
-#if	L1
+#if	FBSD64 | L1
 	fprintf(stderr,"\n\nForwards stack:    (ffpt = %8lx)\n",(INT) ffpt);
 #endif
 	n = ffpt + 30;
@@ -937,20 +942,20 @@ INT	*fin;
 #if	MSC | ZTC
 			fprintf(stderr,"\n%4x:  ",(int) i);
 #endif
-#if	ATT3B | BSD4 | FBSD | IBMC | VMS | WIN | ZTCX
+#if	ATT3B | BSD4 | FBSD32 | IBMC | VMS | WIN | ZTCX
 			fprintf(stderr,"\n%8x:  ",(int) i);
 #endif
-#if	L1
+#if	FBSD64 | L1
 			fprintf(stderr,"\n%8lx:  ",(INT) i);
 #endif
 		}
 #if	MSC | ZTC
 		fprintf(stderr,"  %4x",*i);
 #endif
-#if	ATT3B | BSD4 | FBSD | IBMC | VMS | WIN | ZTCX
+#if	ATT3B | BSD4 | FBSD32 | IBMC | VMS | WIN | ZTCX
 		fprintf(stderr,"  %8x",*i);
 #endif
-#if	L1
+#if	FBSD64 | L1
 		fprintf(stderr,"  %8lx",*i);
 #endif
 		online++;
@@ -965,3 +970,4 @@ INT	*fin;
  *                     *
  ***********************
  */
+
