@@ -5,7 +5,7 @@
  *                                                                    *
  *   Module 2 - Main scanning routine                                 *
  *                                                                    *
- *   Copyright (C) R.D. Eager                        MCMXCIV          *
+ *   Copyright (C) R.D. Eager                        MMXVIII          *
  *                 P.J. Brown   University of Kent   MCMLXVII         *
  *                                                                    *
  **********************************************************************
@@ -62,7 +62,6 @@ static	VOID	stkarg();
 static	jmp_buf	sasave;			/* Transfers control to 'stkarg' return switch */
 static	int	jmp_sw;			/* Used by 'stkarg' return switch */
 
-
 VOID basic_scan()
 /* The main scanning routine. This routine is NOT recursive in the
 normal C sense; however, recursion is effected by stacking the
@@ -130,7 +129,7 @@ fixed closure point. */
 	for(;;) {
 		masksw = sdb.hashpt[LHV + 4] & glbwsw;
 
-		sbstpl();
+		sbstpl();	/* Decide whether to copy, stack or discard text */
 		bespt = ZEROPT;
 
 	bsloop:
@@ -349,7 +348,7 @@ fixed closure point. */
 
 		if(caltyp < UINSMK) {		/* Test for insert or straight-scan macro */
 			if(sdb.skval != 0) {	/* Still searching for label - forget the call */
-				lfpt = nargpt + SDBSZ;
+				lfpt = nargpt + (INT) SDBSZ;
 				continue;
 			}
 			invoct++;
@@ -912,7 +911,7 @@ fixed closure point. */
 
 				/* Set new limit on appropriate local constructions */
 
-				sdb.hashpt[LHV + opmtype] = (INT) (sdb.dbugpt + SDBSZ);
+				sdb.hashpt[LHV + opmtype] = (INT) (sdb.dbugpt + (INT) SDBSZ);
 				opexit();
 				continue;
 
@@ -1369,10 +1368,10 @@ any local variables extant in addition to those declared at the start of
 	sdb.spt = eriapt - 1;
 	sdb.dbugsw = DB_EVAL;
 
-#if	ATT3B | BSD4 | FBSD | IBMC | MSC | VMS | WIN | ZTC | ZTCX
+#if	ATT3B | BSD4 | FBSD32 | IBMC | MSC | VMS | WIN | ZTC | ZTCX
 	longjmp(sasave,opdb.linkpt);		/* Resume processing of outer call */
 #endif
-#if	L1
+#if	FBSD64 | L1
 	longjmp(sasave,(int) opdb.linkpt);	/* Resume processing of outer call */
 #endif
 }
