@@ -5,7 +5,7 @@
  *                                                                    *
  *   Module 3 - Main subroutines                                      *
  *                                                                    *
- *   Copyright (C) R.D. Eager                        MCMXCIV          *
+ *   Copyright (C) R.D. Eager                        MMXVIII          *
  *                 P.J. Brown   University of Kent   MCMLXVII         *
  *                                                                    *
  **********************************************************************
@@ -156,7 +156,7 @@ INT	n;
 #endif
 /* Routine to decrease 'lfpt', checking for stack overflow. */
 {
-#if	ATT3B | BSD4 | FBSD | IBMC | MSC | VMS | WIN | ZTC | ZTCX
+#if	ATT3B | BSD4 | FBSD32 | FBSD64 | IBMC | MSC | VMS | WIN | ZTC | ZTCX
 	lfpt -= n;
 	if(ffpt >= lfpt) erlso();
 #endif
@@ -357,12 +357,12 @@ to 1. */
 #if	IBMC
 #pragma	checkout(suspend)
 #endif
-#if	FBSD
+#if	FBSD32 | FBSD64
 #pragma	clang diagnostic push
 #pragma	clang diagnostic ignored "-Wreturn-type"
 #endif
 }
-#if	FBSD
+#if	FBSD32 | FBSD64
 #pragma	clang diagnostic pop
 #endif
 #if	IBMC
@@ -1012,3 +1012,4 @@ and handles conversion of the argument if required. */
  *                     *
  ***********************
  */
+
