@@ -5,7 +5,7 @@
  *                                                                    *
  *   Common header file                                               *
  *                                                                    *
- *   Copyright (C) R.D. Eager                        MCMXCIV          *
+ *   Copyright (C) R.D. Eager                        MMXVIII          *
  *                 P.J. Brown   University of Kent   MCMLXVII         *
  *                                                                    *
  **********************************************************************
@@ -39,6 +39,7 @@
  * CKM  --  Added support for Microsoft Windows (32 bit).
  * CKN  --  Added support for gcc on FreeBSD.
  * CKO  --  Added support for clang on FreeBSD.
+ * CKP  --  Added support for 64 bit clang on FreeBSD.
  *
  */
 
@@ -51,7 +52,8 @@
 
    ATT3B        - AT&T 3B series (UNIX)
    BSD4         - Berkeley UNIX version 4.x
-   FBSD		- GCC/CLANG on FreeBSD
+   FBSD32	- GCC/CLANG on FreeBSD (32 bit)
+   FBSD64	- CLANG on FreeBSD (64 bit)
    IBMC         - IBM C Set/2 on OS/2
    L1           - MOS-X on Olivetti Line 1
    MSC          - Microsoft C on the IBM PC and PS/2 under OS/2 and DOS
@@ -71,9 +73,10 @@
 #define	WIN		0
 #define ZTC             0
 #define ZTCX            0
-#define	FBSD		1
+#define	FBSD32		1
+#define	FBSD64		0
 
-#if     IBMC | FBSD | MSC | ZTCX | VMS | WIN | ZTC
+#if     IBMC | FBSD32 | FBSD64 | MSC | ZTCX | VMS | WIN | ZTC
 #define ANSI            1
 #else
 #define ANSI            0
@@ -88,11 +91,11 @@
 
 /*** Machine dependent constants ***/
 
-#if     ATT3B | BSD4 | FBSD | IBMC | VMS | WIN
+#if     ATT3B | BSD4 | FBSD32 | IBMC | VMS | WIN
 #define MAXINT  0x7fffffff              /* Largest positive number */
 #endif
-#if     L1 | ZTCX
-#define MAXINT  0x7fffffffL             /* Largest positive number */
+#if     FBSD64 | L1 | ZTCX
+#define MAXINT  0x7fffffffffffffffL     /* Largest positive number */
 #endif
 #if     MSC | ZTC
 #define MAXINT  32767                   /* Largest positive number */
@@ -101,10 +104,10 @@
 
 /*** Machine dependent type definitions ***/
 
-#if     ATT3B | BSD4 | FBSD | IBMC | MSC | VMS | WIN | ZTC | ZTCX
+#if     ATT3B | BSD4 | FBSD32 | IBMC | MSC | VMS | WIN | ZTC | ZTCX
 typedef int     INT;
 #endif
-#if     L1
+#if     FBSD64 | L1
 typedef long    INT;
 #endif
 
@@ -122,7 +125,7 @@ typedef long    INT;
 
 /*** Version number ***/
 
-#define MIVERSION       "CKO"           /* Version number of machine independent logic */
+#define MIVERSION       "CKP"           /* Version number of machine independent logic */
 
 
 /*** Tunable values ***/
@@ -145,11 +148,11 @@ typedef long    INT;
 
 /*** Miscellaneous constants ***/
 
-#if     ATT3B | BSD4 | FBSD | IBMC | MSC | VMS | WIN | ZTC | ZTCX
+#if     ATT3B | BSD4 | FBSD32 | IBMC | MSC | VMS | WIN | ZTC | ZTCX
 #define ZEROPT          ((INT *) 0)     /* Must be less than or equal to any pointer value */
 #define NULLPT          ((INT *) 0)     /* Must be different from any pointer value */
 #endif
-#if     L1
+#if     FBSD64 | L1
 #define ZEROPT          ((INT *) 0L)    /* Must be less than or equal to any pointer value */
 #define NULLPT          ((INT *) 0L)    /* Must be different from any pointer value */
 #endif
@@ -260,8 +263,8 @@ INT     *mtchpt;                        /* Points at orlink when a nested constr
 INT     *stoppt;                        /* Points one beyond last character of current text */
 INT     *labpt;                         /* Head of chain of labels */
 INT     *inffpt;                        /* Points at start of source text on forwards stack */
-INT     skval;                          /* Number of designated label for forward MCGO */
-INT     sklin;                          /* Line number in which MCGO occurred */
+INT     skval;                          /* Number of designated label for forward MC-GO */
+INT     sklin;                          /* Line number in which MC-GO occurred */
 INT     ohsw;                           /* TRUE if a new hash table has been stacked for this level, otherwise FALSE */
 };
 extern  struct  sdbf    sdb;
@@ -606,3 +609,4 @@ extern  INT     mdread();               /* Main input routine */
  *                                  *
  ************************************
  */
+
